@@ -13,7 +13,21 @@
 
 """Implement JSONField for SQLAlchemy."""
 
-from .jsonfield import JSONField, mutable_json_field
+# Local Implementation
+from .jsonfield import JSONField
+from .jsonfield import mutable_json_field
+
+try:
+    # Local Implementation
+    from ._version import version as __version__
+except ImportError:
+    pass
+
+
+__all__ = ("JSONField", "mutable_json_field")
 
-__version__ = '0.6.4'
 __author__ = "Alexey Stepanov <penguinolog@gmail.com>"
+__author_email__ = "penguinolog@gmail.com"
+__url__ = "https://github.com/penguinolog/sqlalchemy_jsonfield"
+__description__ = "SQLALchemy JSONField implementation for storing dicts at SQL"
+__license__ = "Apache License, Version 2.0"
